Index: doc/users/plotting/examples/demo_gridspec06.py
===================================================================
--- doc/users/plotting/examples/demo_gridspec06.py	(revision 0)
+++ doc/users/plotting/examples/demo_gridspec06.py	(revision 0)
@@ -0,0 +1,41 @@
+import matplotlib.pyplot as plt
+import matplotlib.gridspec as gridspec
+import numpy as np
+from itertools import product
+
+def squiggle_xy(a, b, c, d, i=np.arange(0.0, 2*np.pi, 0.05)):
+    return np.sin(i*a)*np.cos(i*b), np.sin(i*c)*np.cos(i*d)
+
+f = plt.figure(figsize=(8, 8))
+
+# gridspec inside gridspec
+outer_grid = gridspec.GridSpec(4, 4, wspace=0.0, hspace=0.0)
+
+for i in xrange(16):
+    inner_grid = gridspec.GridSpecFromSubplotSpec(3, 3,
+            subplot_spec=outer_grid[i], wspace=0.0, hspace=0.0)
+    a, b = int(i/4)+1,i%4+1
+    for j, (c, d) in enumerate(product(range(1, 4), repeat=2)):
+        ax = plt.Subplot(f, inner_grid[j])
+        ax.plot(*squiggle_xy(a, b, c, d))
+        ax.set_xticks([])
+        ax.set_yticks([])
+        f.add_subplot(ax)
+
+all_axes = f.get_axes()
+
+#show only the outside spines
+for ax in all_axes:
+    for sp in ax.spines.values():
+        sp.set_visible(False)
+    if ax.is_first_row():
+        ax.spines['top'].set_visible(True)
+    if ax.is_last_row():
+        ax.spines['bottom'].set_visible(True)
+    if ax.is_first_col():
+        ax.spines['left'].set_visible(True)
+    if ax.is_last_col():
+        ax.spines['right'].set_visible(True)
+
+plt.show()
+
Index: doc/users/gridspec.rst
===================================================================
--- doc/users/gridspec.rst	(revision 8885)
+++ doc/users/gridspec.rst	(working copy)
@@ -1,4 +1,4 @@
-\.. _gridspec-guide:
+.. _gridspec-guide:
 
 
 ************************************************
@@ -129,6 +129,16 @@
 .. plot:: users/plotting/examples/demo_gridspec04.py
 
 
+A Complex Nested GridSpec using SubplotSpec
+===========================================
+
+Here's a more sophisticated example of nested gridspec where we put
+a box around each cell of the outer 4x4 grid, by hiding appropriate 
+spines in each of the inner 3x3 grids. ::
+
+.. plot:: users/plotting/examples/demo_gridspec06.py
+
+
 GridSpec with Varying Cell Sizes
 ================================
 
